@@ -1,5 +1,7 @@
 """
-Main interface for codeguru-reviewer service literal definitions.
+Type annotations for codeguru-reviewer service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/literals.html)
 
 Usage::
 
